@@ -2,14 +2,27 @@ if ("undefined" == typeof(ImapAclExt)) {
 	var ImapAclExt = {};
 };
  if ("undefined" == typeof(ImapAclExt.Utils)) {
+  Components.utils.import("resource:///modules/iteratorUtils.jsm");
   ImapAclExt.Utils = {
 	TIMEOUT : 5,
 	//more than ms, faar less than s
 	COMMANDTIMEOUT : 100,
 	Cc : Components.classes,
 	Ci : Components.interfaces,
-	
+	Cu : Components.utils,
+
 	getSubFoldersAsArray : function (imapFolder, folders) {
+		let allFolders = this.Cc["@mozilla.org/supports-array;1"].createInstance(this.Ci.nsISupportsArray);
+		imapFolder.ListDescendents(allFolders);
+		
+		for each (var folder in fixIterator(allFolders, this.Ci.nsIMsgFolder)) {
+			var imapF = folder.QueryInterface(Components.interfaces.nsIMsgImapMailFolder);
+			
+			if (imapF.canOpenFolder) {
+				folders.push(imapF.onlineName);
+			}
+		}
+		/*
 		var subFolders = imapFolder.subFolders;
 		var numSubFolders = imapFolder.numSubFolders;
 		
@@ -25,7 +38,8 @@ if ("undefined" == typeof(ImapAclExt)) {
 			} catch (ex) {
 				window.dump(ex);
 			}
-		}	
+		}
+		*/
 	},
 	
 	setAcl : function (imapFolder, user, acl, rec, callback, cbSender) {
@@ -177,11 +191,13 @@ if ("undefined" == typeof(ImapAclExt)) {
 		var initialized = false;
 		var protocolData = new Array();
 		var result;
+		var prefs = Components.classes['@mozilla.org/preferences-service;1'].getService(this.Ci.nsIPrefBranch);
 		try {		
 			var secType = null;
 			var secLength = 0;
 			var starttlsMode = false;
-			
+			var startedtlsMode = false;
+
 			if (server.socketType == 3) {
 				secType = ['ssl'];
 				secLength = 1;
@@ -225,7 +241,7 @@ if ("undefined" == typeof(ImapAclExt)) {
 				}
 			}
 			protocolData.push("c004 LOGOUT" + "\r\n");
-					
+
 			var dataListener =
 			{
 				callback : null,
@@ -273,14 +289,18 @@ if ("undefined" == typeof(ImapAclExt)) {
 				onDataAvailable: function(request, context, inputStream, offset, count)
 				{
 					let inputData = instream.read(count);
-					
-					if (starttlsMode && inputData.indexOf("a001") == 0 && 
-						inputData.indexOf("OK") != -1 && inputData.indexOf("TLS") != -1) {
-						transport.securityInfo.StartTLS();
-					} 
-										
+
+					if (starttlsMode && inputData.indexOf("a001") == 0 && inputData.indexOf("OK") != -1) {
+                                                transport.securityInfo.StartTLS();
+						startedtlsMode = true;
+                                        }					
 					this.data.push(inputData);
 					
+					if (index < protocolData.length && index > 0 && starttlsMode && !startedtlsMode) {
+						window.alert("Could not establish TLS Connection");
+						index = protocolData.length-1;
+					}
+
 					if (index < protocolData.length) {
 						let outputData = protocolData[index++];
 						outstream.write(outputData, outputData.length);
@@ -302,6 +322,8 @@ if ("undefined" == typeof(ImapAclExt)) {
 
 			if (starttlsMode) {
 				transport.securityInfo.QueryInterface(this.Ci.nsISSLSocketControl);
+				//var secure = transport.securityInfo.QueryInterface(this.Ci.nsISSLSocketControl);
+				//window.alert(ImapAclExt.Debug.var_dump(secure));
 			}
 			
 			
@@ -317,7 +339,6 @@ if ("undefined" == typeof(ImapAclExt)) {
 			result = ex;
 			window.dump(ex);
 		}
-
 		return result;
 	}
   };
