@@ -43,7 +43,7 @@ if ("undefined" == typeof(ImapAclExt.Aclist)) {
 		cbSender._rights = rights;
 
 		if (cbSender._rights == undefined) {
-			cbSender._doc.getElementById("status_label").value = this._stringBundle.getString("loadingFailed");
+			cbSender._doc.getElementById("status_label").value = cbSender._stringBundle.getString("loadingFailed");
 		} else {
 			for (var i=0; i<cbSender._rights.length;++i) {
 				var username = cbSender._rights[i].username;
@@ -65,7 +65,12 @@ if ("undefined" == typeof(ImapAclExt.Aclist)) {
 				cbSender._userList.appendChild(item);
 			}
 
-			cbSender._doc.getElementById("status_label").value = cbSender._stringBundle.getString("loadingDone");
+			//cbSender._doc.getElementById("status_label").value = this._stringBundle.getString("loadingDone");
+			if (("_stringBundle" in cbSender)) {
+				cbSender._doc.getElementById("status_label").value = cbSender._stringBundle.getString("loadingDone");
+			} else if (("getString" in cbSender._doc.getElementById("acls-bundle"))) {
+				cbSender._doc.getElementById("status_label").value = cbSender._doc.getElementById("acls-bundle").getString("loadingDone");
+			}
 		}
 	},
 	
@@ -76,7 +81,7 @@ if ("undefined" == typeof(ImapAclExt.Aclist)) {
 		//window.dump(this._userList.childNodes.length);
 		for (var i=items.length-1;i>0;--i) {
 			//window.dump("found: " + items[i].value + "\n");
-			if (items[i].Cname == "aclRightsListItemName") {
+			if (("Cname" in items[i]) && items[i].Cname == "aclRightsListItemName") {
 			//	window.dump("removed" + items[i].value + "\n");
 				items[i].parentNode.removeChild(items[i]); //items[i].hidden = true;
 			}
@@ -90,7 +95,7 @@ if ("undefined" == typeof(ImapAclExt.Aclist)) {
 		
 		if (selected == -1) {
 			window.alert(this._stringBundle.getString("noEntry"));
-			return "true";
+			return;// "true";
 		}
 
 		var aclstring = new Object();
@@ -106,9 +111,12 @@ if ("undefined" == typeof(ImapAclExt.Aclist)) {
 				this._rights[selected], aclstring, username, window.arguments[0]);		
 		}
 		
-		if (aclstring.value != "Cancel") {
+		if (!("value" in aclstring) || aclstring.value != "Cancel") {
 			this.refresh();
 		}
+		
+		//useless, but avoids warning:
+		//return true;
 	},
 
 	cnew : function() {
@@ -125,7 +133,7 @@ if ("undefined" == typeof(ImapAclExt.Aclist)) {
 			-1, aclstring, username, window.arguments[0]);		
 		}
 		
-		if (aclstring.value != "Cancel") {
+		if (!("value" in aclstring) || aclstring.value != "Cancel") {
 			this.refresh();
 		}
 	},
@@ -149,6 +157,9 @@ if ("undefined" == typeof(ImapAclExt.Aclist)) {
 		} else {
 			document.getElementById("status_label").value = this._stringBundle.getString("loadingDone");
 		}
+		
+		//useless, but avoids warning:
+		return true;
 	},
 	delCB : function (cbSender, result) {
 		if (result != "success") {
@@ -159,7 +170,7 @@ if ("undefined" == typeof(ImapAclExt.Aclist)) {
 			}
 		}
 		cbSender.refresh();
-		cbSender._doc.getElementById("status_label").value = this._stringBundle.getString("loadingDone");
+		cbSender._doc.getElementById("status_label").value = cbSender._stringBundle.getString("loadingDone");
 	},
 	cancel : function () {
 		window.arguments[1].value = "Cancel";
