@@ -2,7 +2,7 @@ if ("undefined" == typeof(ImapAclExt)) {
   var ImapAclExt = {
 	Cc : Components.classes,
 	Ci : Components.interfaces,  
-	IAE_VERSION : "0.2.2",
+	IAE_VERSION : "0.2.6",
 	_stringBundle : null,
 	_pref : null,
 	
@@ -17,16 +17,17 @@ if ("undefined" == typeof(ImapAclExt)) {
 		this.startup();
     	},
 	onMenuItemCommand : function(aEvent) {
-		this.showAclWindow(aEvent);
+		this.showAclWindow(aEvent,null);
 	},
-	onToolbarButtonCommand : function(aEvent) {
-		this.showAclWindow(aEvent);
+	onToolbarButtonCommand : function(aEvent,folder) {
+		this.showAclWindow(aEvent,folder);
 	},
 	onToolbarOverviewButtonCommand : function(aEvent) {
 	  window.openDialog("chrome://imapaclext/content/aclOverview.xul", "aclOverview", "modal=yes,dialog=yes,centerscreen=yes,resizable=yes");
 	},
-	showAclWindow : function(aEvent) {
-	  var imapFolder = this.getCurrendFolder();
+	showAclWindow : function(aEvent,folder) {
+	  var imapFolder = this.getCurrendFolder(folder);
+	  
 	  if (imapFolder != null) {	
 	    if (imapFolder.getPermissionsForUser(imapFolder.server.realUsername).indexOf("a") != -1) {			
 		    var raction = new Object();
@@ -43,24 +44,30 @@ if ("undefined" == typeof(ImapAclExt)) {
 	    }  
 	  }
 	},
-	getCurrendFolder : function() {
-	var imapFolder = null;
-
-	if (typeof(gFolderDisplay) != "undefined" && typeof(gFolderDisplay.displayedFolder) != "undefined" 
-		&& gFolderDisplay.displayedFolder != null) {
-		imapFolder = gFolderDisplay.displayedFolder.QueryInterface(
-						this.Ci.nsIMsgImapMailFolder);
-		if (!imapFolder.verifiedAsOnlineFolder) {
-			window.alert(this._stringBundle.getString("noFolderSelected"));
-			//window.alert("FOLDER OFFLINE");
-			imapFolder = null;
-		}
+	getCurrendFolder : function(imapFolder) {
+	if (imapFolder == null) {
+	  if (typeof(gFolderDisplay) != "undefined" && typeof(gFolderDisplay.displayedFolder) != "undefined" 
+		  && gFolderDisplay.displayedFolder != null) {
+		  imapFolder = gFolderDisplay.displayedFolder.QueryInterface(
+						  this.Ci.nsIMsgImapMailFolder);
+		  if (!imapFolder.verifiedAsOnlineFolder) {
+			  window.alert(this._stringBundle.getString("noFolderSelected"));
+			  //window.alert("FOLDER OFFLINE");
+			  imapFolder = null;
+		  }
+	  }
+	  else {
+		  window.alert(this._stringBundle.getString("noFolderSelected"));
+		  imapFolder = null;
+	  }
+	} else {
+	  imapFolder = imapFolder.QueryInterface(this.Ci.nsIMsgImapMailFolder);
+	  if (!imapFolder.verifiedAsOnlineFolder) {
+		  window.alert(this._stringBundle.getString("noFolderSelected"));
+		  //window.alert("FOLDER OFFLINE");
+		  imapFolder = null;
+	  }
 	}
-	else {
-		window.alert(this._stringBundle.getString("noFolderSelected"));
-		imapFolder = null;
-	}
-	
 	var type = imapFolder.server.type;
 	
 	if (type != "imap") {
@@ -165,7 +172,7 @@ if ("undefined" == typeof(ImapAclExt.SharingButtonObserver)) {
 					iaeshbutton.width = "150px";
 					iaeshbutton.setAttribute("label", ImapAclExt._stringBundle.getString("setAcl"));
 					win.ImapAclExtref = ImapAclExt;
-					iaeshbutton.onclick = function(){ImapAclExt.onToolbarButtonCommand('onSharing')};				
+					iaeshbutton.onclick = function(){ImapAclExt.onToolbarButtonCommand('onSharing',win.gMsgFolder)};				
 					//iaeshbutton.addEventListener("onclick", function(){alert("button");ImapAclExt.onToolbarButtonCommand('onSharing')});
 					win.document.getElementById("imap.FolderPrivileges").parentNode
 						.appendChild(iaeshbutton);
